/*
 *	Network Queueing System (NQS)
 *  This version of NQS is Copyright (C) 1992  John Roman
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 1, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/*
*  PROJECT:     Network Queueing System
*  AUTHOR:      John Roman
*
*  Modification history:
*
*       Version Who     When            Description
*       -------+-------+---------------+-------------------------
*       V01.10  JRR                     Initial version.
*       V01.2   JRR     28-Feb-1992	Added Cosmic V2 changes.
*	V01.3	JRR	17-Jun-1992	Added header.
*/
/*++ scpnqs.h - Network Queueing System
 *
 * $Source: /usr2/jrroma/nqs-3.21/h/RCS/scpnqs.h,v $
 *
 * DESCRIPTION:
 *
 *
 *	SCP interface structures for NQS.
 *
 *
 *	Author:
 *	-------
 *	Clay Andreasen, Cray Research Incorporated
 *	July, 1986.
 *
 *
 * STANDARDS VIOLATIONS:
 *   None.
 *
 * REVISION HISTORY: ($Revision: 1.3 $ $Date: 92/06/18 09:46:30 $ $State: Exp $)
 * $Log:	scpnqs.h,v $
 * Revision 1.3  92/06/18  09:46:30  jrroma
 * Added gnu header
 * 
 * Revision 1.2  92/02/28  13:08:13  jrroma
 * Added Cosmic V2 changes.
 * 
 * Revision 1.1  92/02/28  13:06:46  jrroma
 * Initial revision
 * 
 *
 */
/* CRAYSCCS %Z%%M%	%I%	%G% %U% */

#define PMAJOR	"/usr/spool/uscp"

/*
 *	Definition of structure returned by qstat for each defined queue.
 *	This is followed by a qstat_j structure for each job in the queue.
 */
struct	qstat_q {
	char	qname[16];		/* queue name */
	int	limit;			/* run limit of queue */
	int	running;		/* number of jobs running */
	int	queued;			/* number of jobs queued */
	int	status;			/* 0=off 1 = on */
};

/*
 *	Definition of structure returned by qstat for each job submitted
 *	throuch USCP.  Qstat compares the first part of the standard output
 *	pathname of the job with the string PMAJOR (defined above) to determine
 *	whether the job came through USCP.
 */
struct	qstat_j {
	char	jobname[8];		/* job name */
	char	user[8];		/* user name */
	char	state[8];		/* job state (in ASCII) */
	int	jobid;			/* UNICOS job id (if executing) */
	int	seqno;			/* NQS sequence number */
	int	nice;			/* nice value at initiation */
	int	fl;			/* memory field length (clicks) */
	int	cpu;			/* cpu used (sec) */
	int	limit;			/* cpu time limit (sec) */
	int	scpflag;		/* job came from SCP flag */
};

/*
 *	Definition of structure returned by qsub when executed with a '-*n'
 *	parameter.
 */
struct	qsub_scp {
	int	qsubpid;		/* Process ID of the qsub program */
	int	seqno;			/* NQS sequence number of the job */
	char	jobname[16];		/* Job name */
};
